#[non_exhaustive]pub struct CreateCdnKeyRequest {
pub parent: String,
pub cdn_key: Option<CdnKey>,
pub cdn_key_id: String,
/* private fields */
}Expand description
Request message for VideoStitcherService.createCdnKey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project in which the CDN key should be created, in the form
of projects/{project_number}/locations/{location}.
cdn_key: Option<CdnKey>Required. The CDN key resource to create.
cdn_key_id: StringRequired. The ID to use for the CDN key, which will become the final component of the CDN key’s resource name.
This value should conform to RFC-1034, which restricts to lower-case letters, numbers, and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum.
Implementations
Sourceimpl CreateCdnKeyRequest
impl CreateCdnKeyRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cdn_key<T>(self, v: T) -> Self
pub fn set_cdn_key<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cdn_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cdn_key<T>(self, v: Option<T>) -> Self
Sourcepub fn set_cdn_key_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cdn_key_id<T: Into<String>>(self, v: T) -> Self
Sets the value of cdn_key_id.
Example
ⓘ
let x = CreateCdnKeyRequest::new().set_cdn_key_id("example");Trait Implementations
Sourceimpl Clone for CreateCdnKeyRequest
impl Clone for CreateCdnKeyRequest
Sourcefn clone(&self) -> CreateCdnKeyRequest
fn clone(&self) -> CreateCdnKeyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateCdnKeyRequest
impl Debug for CreateCdnKeyRequest
Sourceimpl Default for CreateCdnKeyRequest
impl Default for CreateCdnKeyRequest
Sourcefn default() -> CreateCdnKeyRequest
fn default() -> CreateCdnKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateCdnKeyRequest
impl Message for CreateCdnKeyRequest
Sourceimpl PartialEq for CreateCdnKeyRequest
impl PartialEq for CreateCdnKeyRequest
Sourcefn eq(&self, other: &CreateCdnKeyRequest) -> bool
fn eq(&self, other: &CreateCdnKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateCdnKeyRequest