#[non_exhaustive]pub struct CreateLiveConfigRequest {
pub parent: String,
pub live_config_id: String,
pub live_config: Option<LiveConfig>,
pub request_id: String,
/* private fields */
}Expand description
Request message for VideoStitcherService.createLiveConfig
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project in which the live config should be created, in
the form of projects/{project_number}/locations/{location}.
live_config_id: StringRequired. The unique identifier ID to use for the live config.
live_config: Option<LiveConfig>Required. The live config resource to create.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is
not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateLiveConfigRequest
impl CreateLiveConfigRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_live_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_live_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of live_config_id.
Example
let x = CreateLiveConfigRequest::new().set_live_config_id("example");Sourcepub fn set_live_config<T>(self, v: T) -> Selfwhere
T: Into<LiveConfig>,
pub fn set_live_config<T>(self, v: T) -> Selfwhere
T: Into<LiveConfig>,
Sets the value of live_config.
Example
use google_cloud_video_stitcher_v1::model::LiveConfig;
let x = CreateLiveConfigRequest::new().set_live_config(LiveConfig::default()/* use setters */);Sourcepub fn set_or_clear_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveConfig>,
pub fn set_or_clear_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveConfig>,
Sets or clears the value of live_config.
Example
use google_cloud_video_stitcher_v1::model::LiveConfig;
let x = CreateLiveConfigRequest::new().set_or_clear_live_config(Some(LiveConfig::default()/* use setters */));
let x = CreateLiveConfigRequest::new().set_or_clear_live_config(None::<LiveConfig>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateLiveConfigRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateLiveConfigRequest
impl Clone for CreateLiveConfigRequest
Sourcefn clone(&self) -> CreateLiveConfigRequest
fn clone(&self) -> CreateLiveConfigRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateLiveConfigRequest
impl Debug for CreateLiveConfigRequest
Sourceimpl Default for CreateLiveConfigRequest
impl Default for CreateLiveConfigRequest
Sourcefn default() -> CreateLiveConfigRequest
fn default() -> CreateLiveConfigRequest
Sourceimpl Message for CreateLiveConfigRequest
impl Message for CreateLiveConfigRequest
Sourceimpl PartialEq for CreateLiveConfigRequest
impl PartialEq for CreateLiveConfigRequest
Sourcefn eq(&self, other: &CreateLiveConfigRequest) -> bool
fn eq(&self, other: &CreateLiveConfigRequest) -> bool
self and other values to be equal, and is used by ==.