#[non_exhaustive]pub struct CreateLiveSessionRequest {
pub parent: String,
pub live_session: Option<LiveSession>,
/* private fields */
}Expand description
Request message for VideoStitcherService.createLiveSession.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project and location in which the live session should be
created, in the form of projects/{project_number}/locations/{location}.
live_session: Option<LiveSession>Required. Parameters for creating a live session.
Implementations
Sourceimpl CreateLiveSessionRequest
impl CreateLiveSessionRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_live_session<T>(self, v: T) -> Selfwhere
T: Into<LiveSession>,
pub fn set_live_session<T>(self, v: T) -> Selfwhere
T: Into<LiveSession>,
Sets the value of live_session.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::LiveSession;
let x = CreateLiveSessionRequest::new().set_live_session(LiveSession::default()/* use setters */);Sourcepub fn set_or_clear_live_session<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveSession>,
pub fn set_or_clear_live_session<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveSession>,
Sets or clears the value of live_session.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::LiveSession;
let x = CreateLiveSessionRequest::new().set_or_clear_live_session(Some(LiveSession::default()/* use setters */));
let x = CreateLiveSessionRequest::new().set_or_clear_live_session(None::<LiveSession>);Trait Implementations
Sourceimpl Clone for CreateLiveSessionRequest
impl Clone for CreateLiveSessionRequest
Sourcefn clone(&self) -> CreateLiveSessionRequest
fn clone(&self) -> CreateLiveSessionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateLiveSessionRequest
impl Debug for CreateLiveSessionRequest
Sourceimpl Default for CreateLiveSessionRequest
impl Default for CreateLiveSessionRequest
Sourcefn default() -> CreateLiveSessionRequest
fn default() -> CreateLiveSessionRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateLiveSessionRequest
impl Message for CreateLiveSessionRequest
Sourceimpl PartialEq for CreateLiveSessionRequest
impl PartialEq for CreateLiveSessionRequest
Sourcefn eq(&self, other: &CreateLiveSessionRequest) -> bool
fn eq(&self, other: &CreateLiveSessionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateLiveSessionRequest