#[non_exhaustive]pub struct CreateSlateRequest {
pub parent: String,
pub slate_id: String,
pub slate: Option<Slate>,
pub request_id: String,
/* private fields */
}Expand description
Request message for VideoStitcherService.createSlate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project in which the slate should be created, in the form of
projects/{project_number}/locations/{location}.
slate_id: StringRequired. The unique identifier for the slate. This value should conform to RFC-1034, which restricts to lower-case letters, numbers, and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum.
slate: Option<Slate>Required. The slate to create.
request_id: StringA request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is
not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateSlateRequest
impl CreateSlateRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_slate_id<T: Into<String>>(self, v: T) -> Self
pub fn set_slate_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_slate<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_slate<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSlateRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateSlateRequest
impl Clone for CreateSlateRequest
Sourcefn clone(&self) -> CreateSlateRequest
fn clone(&self) -> CreateSlateRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateSlateRequest
impl Debug for CreateSlateRequest
Sourceimpl Default for CreateSlateRequest
impl Default for CreateSlateRequest
Sourcefn default() -> CreateSlateRequest
fn default() -> CreateSlateRequest
Sourceimpl Message for CreateSlateRequest
impl Message for CreateSlateRequest
Sourceimpl PartialEq for CreateSlateRequest
impl PartialEq for CreateSlateRequest
Sourcefn eq(&self, other: &CreateSlateRequest) -> bool
fn eq(&self, other: &CreateSlateRequest) -> bool
self and other values to be equal, and is used by ==.