#[non_exhaustive]pub struct CreateVodConfigRequest {
pub parent: String,
pub vod_config_id: String,
pub vod_config: Option<VodConfig>,
pub request_id: String,
/* private fields */
}Expand description
Request message for VideoStitcherService.createVodConfig
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The project in which the VOD config should be created, in
the form of projects/{project_number}/locations/{location}.
vod_config_id: StringRequired. The unique identifier ID to use for the VOD config.
vod_config: Option<VodConfig>Required. The VOD config resource to create.
request_id: StringOptional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is
not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateVodConfigRequest
impl CreateVodConfigRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_vod_config_id<T: Into<String>>(self, v: T) -> Self
pub fn set_vod_config_id<T: Into<String>>(self, v: T) -> Self
Sets the value of vod_config_id.
Example
let x = CreateVodConfigRequest::new().set_vod_config_id("example");Sourcepub fn set_vod_config<T>(self, v: T) -> Self
pub fn set_vod_config<T>(self, v: T) -> Self
Sets the value of vod_config.
Example
use google_cloud_video_stitcher_v1::model::VodConfig;
let x = CreateVodConfigRequest::new().set_vod_config(VodConfig::default()/* use setters */);Sourcepub fn set_or_clear_vod_config<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_vod_config<T>(self, v: Option<T>) -> Self
Sets or clears the value of vod_config.
Example
use google_cloud_video_stitcher_v1::model::VodConfig;
let x = CreateVodConfigRequest::new().set_or_clear_vod_config(Some(VodConfig::default()/* use setters */));
let x = CreateVodConfigRequest::new().set_or_clear_vod_config(None::<VodConfig>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateVodConfigRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateVodConfigRequest
impl Clone for CreateVodConfigRequest
Sourcefn clone(&self) -> CreateVodConfigRequest
fn clone(&self) -> CreateVodConfigRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CreateVodConfigRequest
impl Debug for CreateVodConfigRequest
Sourceimpl Default for CreateVodConfigRequest
impl Default for CreateVodConfigRequest
Sourcefn default() -> CreateVodConfigRequest
fn default() -> CreateVodConfigRequest
Sourceimpl Message for CreateVodConfigRequest
impl Message for CreateVodConfigRequest
Sourceimpl PartialEq for CreateVodConfigRequest
impl PartialEq for CreateVodConfigRequest
Sourcefn eq(&self, other: &CreateVodConfigRequest) -> bool
fn eq(&self, other: &CreateVodConfigRequest) -> bool
self and other values to be equal, and is used by ==.