LiveConfig

Struct LiveConfig 

#[non_exhaustive]
pub struct LiveConfig { pub name: String, pub source_uri: String, pub ad_tag_uri: String, pub gam_live_config: Option<GamLiveConfig>, pub state: State, pub ad_tracking: AdTracking, pub default_slate: String, pub stitching_policy: StitchingPolicy, pub prefetch_config: Option<PrefetchConfig>, pub source_fetch_options: Option<FetchOptions>, /* private fields */ }
Metadata for used to register live configs.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. The resource name of the live config, in the form of projects/{project}/locations/{location}/liveConfigs/{id}.

source_uri: String

Required. Source URI for the live stream manifest.

ad_tag_uri: String

The default ad tag associated with this live stream config.

gam_live_config: Option<GamLiveConfig>

Additional metadata used to register a live stream with Google Ad Manager (GAM)

state: State

Output only. State of the live config.

ad_tracking: AdTracking

Required. Determines how the ads are tracked.

default_slate: String

This must refer to a slate in the same project. If Google Ad Manager (GAM) is used for ads, this string sets the value of slateCreativeId in https://developers.google.com/ad-manager/api/reference/v202211/LiveStreamEventService.LiveStreamEvent#slateCreativeId

stitching_policy: StitchingPolicy

Defines the stitcher behavior in case an ad does not align exactly with the ad break boundaries. If not specified, the default is CUT_CURRENT.

prefetch_config: Option<PrefetchConfig>

The configuration for prefetching ads.

source_fetch_options: Option<FetchOptions>

Options for fetching source manifests and segments.

Implementations

Source

impl LiveConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = LiveConfig::new().set_name(format!("projects/{project_id}/locations/{location_id}/liveConfigs/{live_config_id}"));
pub fn set_source_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of source_uri.

Example
let x = LiveConfig::new().set_source_uri("example");
pub fn set_ad_tag_uri<T: Into<String>>(self, v: T) -> Self

Sets the value of ad_tag_uri.

Example
let x = LiveConfig::new().set_ad_tag_uri("example");
pub fn set_gam_live_config<T>(self, v: T) -> Self
where T: Into<GamLiveConfig>,

Sets the value of gam_live_config.

Example
use google_cloud_video_stitcher_v1::model::GamLiveConfig;
let x = LiveConfig::new().set_gam_live_config(GamLiveConfig::default()/* use setters */);
pub fn set_or_clear_gam_live_config<T>(self, v: Option<T>) -> Self
where T: Into<GamLiveConfig>,

Sets or clears the value of gam_live_config.

Example
use google_cloud_video_stitcher_v1::model::GamLiveConfig;
let x = LiveConfig::new().set_or_clear_gam_live_config(Some(GamLiveConfig::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_gam_live_config(None::<GamLiveConfig>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_video_stitcher_v1::model::live_config::State;
let x0 = LiveConfig::new().set_state(State::Creating);
let x1 = LiveConfig::new().set_state(State::Ready);
let x2 = LiveConfig::new().set_state(State::Deleting);
pub fn set_ad_tracking<T: Into<AdTracking>>(self, v: T) -> Self

Sets the value of ad_tracking.

Example
use google_cloud_video_stitcher_v1::model::AdTracking;
let x0 = LiveConfig::new().set_ad_tracking(AdTracking::Client);
let x1 = LiveConfig::new().set_ad_tracking(AdTracking::Server);
pub fn set_default_slate<T: Into<String>>(self, v: T) -> Self

Sets the value of default_slate.

Example
let x = LiveConfig::new().set_default_slate(format!("projects/{project_id}/locations/{location_id}/slates/{slate_id}"));
pub fn set_stitching_policy<T: Into<StitchingPolicy>>(self, v: T) -> Self

Sets the value of stitching_policy.

Example
use google_cloud_video_stitcher_v1::model::live_config::StitchingPolicy;
let x0 = LiveConfig::new().set_stitching_policy(StitchingPolicy::CutCurrent);
let x1 = LiveConfig::new().set_stitching_policy(StitchingPolicy::CompleteAd);
pub fn set_prefetch_config<T>(self, v: T) -> Self
where T: Into<PrefetchConfig>,

Sets the value of prefetch_config.

Example
use google_cloud_video_stitcher_v1::model::PrefetchConfig;
let x = LiveConfig::new().set_prefetch_config(PrefetchConfig::default()/* use setters */);
pub fn set_or_clear_prefetch_config<T>(self, v: Option<T>) -> Self
where T: Into<PrefetchConfig>,

Sets or clears the value of prefetch_config.

Example
use google_cloud_video_stitcher_v1::model::PrefetchConfig;
let x = LiveConfig::new().set_or_clear_prefetch_config(Some(PrefetchConfig::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_prefetch_config(None::<PrefetchConfig>);
pub fn set_source_fetch_options<T>(self, v: T) -> Self
where T: Into<FetchOptions>,

Sets the value of source_fetch_options.

Example
use google_cloud_video_stitcher_v1::model::FetchOptions;
let x = LiveConfig::new().set_source_fetch_options(FetchOptions::default()/* use setters */);
pub fn set_or_clear_source_fetch_options<T>(self, v: Option<T>) -> Self
where T: Into<FetchOptions>,

Sets or clears the value of source_fetch_options.

Example
use google_cloud_video_stitcher_v1::model::FetchOptions;
let x = LiveConfig::new().set_or_clear_source_fetch_options(Some(FetchOptions::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_source_fetch_options(None::<FetchOptions>);