PrefetchConfig

Struct PrefetchConfig 

#[non_exhaustive]
pub struct PrefetchConfig { pub enabled: bool, pub initial_ad_request_duration: Option<Duration>, /* private fields */ }
The configuration for prefetch ads.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enabled: bool

Required. Indicates whether the option to prefetch ad requests is enabled.

initial_ad_request_duration: Option<Duration>

The duration in seconds of the part of the break to be prefetched. This field is only relevant if prefetch is enabled. You should set this duration to as long as possible to increase the benefits of prefetching, but not longer than the shortest ad break expected. For example, for a live event with 30s and 60s ad breaks, the initial duration should be set to 30s.

Implementations

Source

impl PrefetchConfig

pub fn new() -> Self

Creates a new default instance.

pub fn set_enabled<T: Into<bool>>(self, v: T) -> Self

Sets the value of enabled.

Example
let x = PrefetchConfig::new().set_enabled(true);
pub fn set_initial_ad_request_duration<T>(self, v: T) -> Self
where T: Into<Duration>,

Sets the value of initial_ad_request_duration.

Example
use wkt::Duration;
let x = PrefetchConfig::new().set_initial_ad_request_duration(Duration::default()/* use setters */);
pub fn set_or_clear_initial_ad_request_duration<T>(self, v: Option<T>) -> Self
where T: Into<Duration>,

Sets or clears the value of initial_ad_request_duration.

Example
use wkt::Duration;
let x = PrefetchConfig::new().set_or_clear_initial_ad_request_duration(Some(Duration::default()/* use setters */));
let x = PrefetchConfig::new().set_or_clear_initial_ad_request_duration(None::<Duration>);