#[non_exhaustive]pub struct ProgressEvent {
pub time_offset: Option<Duration>,
pub events: Vec<Event>,
/* private fields */
}Expand description
Indicates a time in which a list of events should be triggered during media playback.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.time_offset: Option<Duration>The time when the following tracking events occurs. The time is in seconds relative to the start of the VOD asset.
events: Vec<Event>The list of progress tracking events for the ad break. These can be of
the following IAB types: BREAK_START, BREAK_END, IMPRESSION,
CREATIVE_VIEW, START, FIRST_QUARTILE, MIDPOINT, THIRD_QUARTILE,
COMPLETE, PROGRESS.
Implementations
Sourceimpl ProgressEvent
impl ProgressEvent
Sourcepub fn set_time_offset<T>(self, v: T) -> Self
pub fn set_time_offset<T>(self, v: T) -> Self
Sets the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ProgressEvent::new().set_time_offset(Duration::default()/* use setters */);Sourcepub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_time_offset<T>(self, v: Option<T>) -> Self
Sets or clears the value of time_offset.
Example
ⓘ
use wkt::Duration;
let x = ProgressEvent::new().set_or_clear_time_offset(Some(Duration::default()/* use setters */));
let x = ProgressEvent::new().set_or_clear_time_offset(None::<Duration>);Sourcepub fn set_events<T, V>(self, v: T) -> Self
pub fn set_events<T, V>(self, v: T) -> Self