#[non_exhaustive]pub struct UpdateCdnKeyRequest {
pub cdn_key: Option<CdnKey>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for VideoStitcherService.updateCdnKey.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cdn_key: Option<CdnKey>Required. The CDN key resource which replaces the resource on the server.
update_mask: Option<FieldMask>Required. The update mask applies to the resource.
For the FieldMask definition, see
https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
Implementations
Sourceimpl UpdateCdnKeyRequest
impl UpdateCdnKeyRequest
Sourcepub fn set_cdn_key<T>(self, v: T) -> Self
pub fn set_cdn_key<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cdn_key<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cdn_key<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCdnKeyRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateCdnKeyRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateCdnKeyRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateCdnKeyRequest
impl Clone for UpdateCdnKeyRequest
Sourcefn clone(&self) -> UpdateCdnKeyRequest
fn clone(&self) -> UpdateCdnKeyRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateCdnKeyRequest
impl Debug for UpdateCdnKeyRequest
Sourceimpl Default for UpdateCdnKeyRequest
impl Default for UpdateCdnKeyRequest
Sourcefn default() -> UpdateCdnKeyRequest
fn default() -> UpdateCdnKeyRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateCdnKeyRequest
impl Message for UpdateCdnKeyRequest
Sourceimpl PartialEq for UpdateCdnKeyRequest
impl PartialEq for UpdateCdnKeyRequest
Sourcefn eq(&self, other: &UpdateCdnKeyRequest) -> bool
fn eq(&self, other: &UpdateCdnKeyRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateCdnKeyRequest