#[non_exhaustive]pub struct UpdateLiveConfigRequest {
pub live_config: Option<LiveConfig>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for VideoStitcherService.updateLiveConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.live_config: Option<LiveConfig>Required. The LiveConfig resource which replaces the resource on the server.
update_mask: Option<FieldMask>Required. The update mask applies to the resource.
For the FieldMask definition, see
https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
Implementations
Sourceimpl UpdateLiveConfigRequest
impl UpdateLiveConfigRequest
Sourcepub fn set_live_config<T>(self, v: T) -> Selfwhere
T: Into<LiveConfig>,
pub fn set_live_config<T>(self, v: T) -> Selfwhere
T: Into<LiveConfig>,
Sets the value of live_config.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::LiveConfig;
let x = UpdateLiveConfigRequest::new().set_live_config(LiveConfig::default()/* use setters */);Sourcepub fn set_or_clear_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveConfig>,
pub fn set_or_clear_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<LiveConfig>,
Sets or clears the value of live_config.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::LiveConfig;
let x = UpdateLiveConfigRequest::new().set_or_clear_live_config(Some(LiveConfig::default()/* use setters */));
let x = UpdateLiveConfigRequest::new().set_or_clear_live_config(None::<LiveConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateLiveConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateLiveConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateLiveConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateLiveConfigRequest
impl Clone for UpdateLiveConfigRequest
Sourcefn clone(&self) -> UpdateLiveConfigRequest
fn clone(&self) -> UpdateLiveConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateLiveConfigRequest
impl Debug for UpdateLiveConfigRequest
Sourceimpl Default for UpdateLiveConfigRequest
impl Default for UpdateLiveConfigRequest
Sourcefn default() -> UpdateLiveConfigRequest
fn default() -> UpdateLiveConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateLiveConfigRequest
impl Message for UpdateLiveConfigRequest
Sourceimpl PartialEq for UpdateLiveConfigRequest
impl PartialEq for UpdateLiveConfigRequest
Sourcefn eq(&self, other: &UpdateLiveConfigRequest) -> bool
fn eq(&self, other: &UpdateLiveConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateLiveConfigRequest