#[non_exhaustive]pub struct UpdateVodConfigRequest {
pub vod_config: Option<VodConfig>,
pub update_mask: Option<FieldMask>,
/* private fields */
}Expand description
Request message for VideoStitcherService.updateVodConfig.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vod_config: Option<VodConfig>Required. The VOD config resource which replaces the resource on the server.
update_mask: Option<FieldMask>Required. The update mask applies to the resource.
For the FieldMask definition, see
https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
Implementations
Sourceimpl UpdateVodConfigRequest
impl UpdateVodConfigRequest
Sourcepub fn set_vod_config<T>(self, v: T) -> Self
pub fn set_vod_config<T>(self, v: T) -> Self
Sets the value of vod_config.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::VodConfig;
let x = UpdateVodConfigRequest::new().set_vod_config(VodConfig::default()/* use setters */);Sourcepub fn set_or_clear_vod_config<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_vod_config<T>(self, v: Option<T>) -> Self
Sets or clears the value of vod_config.
Example
ⓘ
use google_cloud_video_stitcher_v1::model::VodConfig;
let x = UpdateVodConfigRequest::new().set_or_clear_vod_config(Some(VodConfig::default()/* use setters */));
let x = UpdateVodConfigRequest::new().set_or_clear_vod_config(None::<VodConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateVodConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateVodConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateVodConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Trait Implementations
Sourceimpl Clone for UpdateVodConfigRequest
impl Clone for UpdateVodConfigRequest
Sourcefn clone(&self) -> UpdateVodConfigRequest
fn clone(&self) -> UpdateVodConfigRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateVodConfigRequest
impl Debug for UpdateVodConfigRequest
Sourceimpl Default for UpdateVodConfigRequest
impl Default for UpdateVodConfigRequest
Sourcefn default() -> UpdateVodConfigRequest
fn default() -> UpdateVodConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateVodConfigRequest
impl Message for UpdateVodConfigRequest
Sourceimpl PartialEq for UpdateVodConfigRequest
impl PartialEq for UpdateVodConfigRequest
Sourcefn eq(&self, other: &UpdateVodConfigRequest) -> bool
fn eq(&self, other: &UpdateVodConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateVodConfigRequest