#[non_exhaustive]pub struct LiveConfig {
pub name: String,
pub source_uri: String,
pub ad_tag_uri: String,
pub gam_live_config: Option<GamLiveConfig>,
pub state: State,
pub ad_tracking: AdTracking,
pub default_slate: String,
pub stitching_policy: StitchingPolicy,
pub prefetch_config: Option<PrefetchConfig>,
pub source_fetch_options: Option<FetchOptions>,
/* private fields */
}Expand description
Metadata for used to register live configs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The resource name of the live config, in the form of
projects/{project}/locations/{location}/liveConfigs/{id}.
source_uri: StringRequired. Source URI for the live stream manifest.
ad_tag_uri: StringThe default ad tag associated with this live stream config.
gam_live_config: Option<GamLiveConfig>Additional metadata used to register a live stream with Google Ad Manager (GAM)
state: StateOutput only. State of the live config.
ad_tracking: AdTrackingRequired. Determines how the ads are tracked.
default_slate: StringThis must refer to a slate in the same
project. If Google Ad Manager (GAM) is used for ads, this string sets the
value of slateCreativeId in
https://developers.google.com/ad-manager/api/reference/v202211/LiveStreamEventService.LiveStreamEvent#slateCreativeId
stitching_policy: StitchingPolicyDefines the stitcher behavior in case an ad does not align exactly with
the ad break boundaries. If not specified, the default is CUT_CURRENT.
prefetch_config: Option<PrefetchConfig>The configuration for prefetching ads.
source_fetch_options: Option<FetchOptions>Options for fetching source manifests and segments.
Implementations
Sourceimpl LiveConfig
impl LiveConfig
Sourcepub fn set_source_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_source_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ad_tag_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_ad_tag_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_gam_live_config<T>(self, v: T) -> Selfwhere
T: Into<GamLiveConfig>,
pub fn set_gam_live_config<T>(self, v: T) -> Selfwhere
T: Into<GamLiveConfig>,
Sets the value of gam_live_config.
Example
use google_cloud_video_stitcher_v1::model::GamLiveConfig;
let x = LiveConfig::new().set_gam_live_config(GamLiveConfig::default()/* use setters */);Sourcepub fn set_or_clear_gam_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<GamLiveConfig>,
pub fn set_or_clear_gam_live_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<GamLiveConfig>,
Sets or clears the value of gam_live_config.
Example
use google_cloud_video_stitcher_v1::model::GamLiveConfig;
let x = LiveConfig::new().set_or_clear_gam_live_config(Some(GamLiveConfig::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_gam_live_config(None::<GamLiveConfig>);Sourcepub fn set_ad_tracking<T: Into<AdTracking>>(self, v: T) -> Self
pub fn set_ad_tracking<T: Into<AdTracking>>(self, v: T) -> Self
Sets the value of ad_tracking.
Example
use google_cloud_video_stitcher_v1::model::AdTracking;
let x0 = LiveConfig::new().set_ad_tracking(AdTracking::Client);
let x1 = LiveConfig::new().set_ad_tracking(AdTracking::Server);Sourcepub fn set_default_slate<T: Into<String>>(self, v: T) -> Self
pub fn set_default_slate<T: Into<String>>(self, v: T) -> Self
Sets the value of default_slate.
Example
let x = LiveConfig::new().set_default_slate(format!("projects/{project_id}/locations/{location_id}/slates/{slate_id}"));Sourcepub fn set_stitching_policy<T: Into<StitchingPolicy>>(self, v: T) -> Self
pub fn set_stitching_policy<T: Into<StitchingPolicy>>(self, v: T) -> Self
Sets the value of stitching_policy.
Example
use google_cloud_video_stitcher_v1::model::live_config::StitchingPolicy;
let x0 = LiveConfig::new().set_stitching_policy(StitchingPolicy::CutCurrent);
let x1 = LiveConfig::new().set_stitching_policy(StitchingPolicy::CompleteAd);Sourcepub fn set_prefetch_config<T>(self, v: T) -> Selfwhere
T: Into<PrefetchConfig>,
pub fn set_prefetch_config<T>(self, v: T) -> Selfwhere
T: Into<PrefetchConfig>,
Sets the value of prefetch_config.
Example
use google_cloud_video_stitcher_v1::model::PrefetchConfig;
let x = LiveConfig::new().set_prefetch_config(PrefetchConfig::default()/* use setters */);Sourcepub fn set_or_clear_prefetch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrefetchConfig>,
pub fn set_or_clear_prefetch_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<PrefetchConfig>,
Sets or clears the value of prefetch_config.
Example
use google_cloud_video_stitcher_v1::model::PrefetchConfig;
let x = LiveConfig::new().set_or_clear_prefetch_config(Some(PrefetchConfig::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_prefetch_config(None::<PrefetchConfig>);Sourcepub fn set_source_fetch_options<T>(self, v: T) -> Selfwhere
T: Into<FetchOptions>,
pub fn set_source_fetch_options<T>(self, v: T) -> Selfwhere
T: Into<FetchOptions>,
Sets the value of source_fetch_options.
Example
use google_cloud_video_stitcher_v1::model::FetchOptions;
let x = LiveConfig::new().set_source_fetch_options(FetchOptions::default()/* use setters */);Sourcepub fn set_or_clear_source_fetch_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<FetchOptions>,
pub fn set_or_clear_source_fetch_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<FetchOptions>,
Sets or clears the value of source_fetch_options.
Example
use google_cloud_video_stitcher_v1::model::FetchOptions;
let x = LiveConfig::new().set_or_clear_source_fetch_options(Some(FetchOptions::default()/* use setters */));
let x = LiveConfig::new().set_or_clear_source_fetch_options(None::<FetchOptions>);Trait Implementations
Sourceimpl Clone for LiveConfig
impl Clone for LiveConfig
Sourcefn clone(&self) -> LiveConfig
fn clone(&self) -> LiveConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LiveConfig
impl Debug for LiveConfig
Sourceimpl Default for LiveConfig
impl Default for LiveConfig
Sourcefn default() -> LiveConfig
fn default() -> LiveConfig
Sourceimpl PartialEq for LiveConfig
impl PartialEq for LiveConfig
Sourcefn eq(&self, other: &LiveConfig) -> bool
fn eq(&self, other: &LiveConfig) -> bool
self and other values to be equal, and is used by ==.