#[non_exhaustive]pub struct LiveSession {
pub name: String,
pub play_uri: String,
pub ad_tag_macros: HashMap<String, String>,
pub manifest_options: Option<ManifestOptions>,
pub gam_settings: Option<GamSettings>,
pub live_config: String,
pub ad_tracking: AdTracking,
/* private fields */
}Expand description
Metadata for a live session. The session expires 5 minutes after the client stops fetching the session’s playlists.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. The name of the live session, in the form of
projects/{project}/locations/{location}/liveSessions/{id}.
play_uri: StringOutput only. The URI to play the live session’s ad-stitched stream.
ad_tag_macros: HashMap<String, String>Key value pairs for ad tag macro replacement, only available for live sessions that do not implement Google Ad manager ad insertion. If the specified ad tag URI has macros, this field provides the mapping to the value that will replace the macro in the ad tag URI.
Macros are designated by square brackets, for example:
Ad tag URI: “https://doubleclick.google.com/ad/1?geo_id=[geoId]”
Ad tag macros: {"geoId": "123"}
Fully qualified ad tag:
https://doubleclick.google.com/ad/1?geo_id=123
manifest_options: Option<ManifestOptions>Additional options that affect the output of the manifest.
gam_settings: Option<GamSettings>This field should be set with appropriate values if GAM is being used for ads.
live_config: StringRequired. The resource name of the live config for this session, in the
form of projects/{project}/locations/{location}/liveConfigs/{id}.
ad_tracking: AdTrackingDetermines how the ad should be tracked. This overrides the value set in the live config for this session.
Implementations
Sourceimpl LiveSession
impl LiveSession
Sourcepub fn set_play_uri<T: Into<String>>(self, v: T) -> Self
pub fn set_play_uri<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_ad_tag_macros<T, K, V>(self, v: T) -> Self
pub fn set_ad_tag_macros<T, K, V>(self, v: T) -> Self
Sets the value of ad_tag_macros.
Example
let x = LiveSession::new().set_ad_tag_macros([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_manifest_options<T>(self, v: T) -> Selfwhere
T: Into<ManifestOptions>,
pub fn set_manifest_options<T>(self, v: T) -> Selfwhere
T: Into<ManifestOptions>,
Sets the value of manifest_options.
Example
use google_cloud_video_stitcher_v1::model::ManifestOptions;
let x = LiveSession::new().set_manifest_options(ManifestOptions::default()/* use setters */);Sourcepub fn set_or_clear_manifest_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<ManifestOptions>,
pub fn set_or_clear_manifest_options<T>(self, v: Option<T>) -> Selfwhere
T: Into<ManifestOptions>,
Sets or clears the value of manifest_options.
Example
use google_cloud_video_stitcher_v1::model::ManifestOptions;
let x = LiveSession::new().set_or_clear_manifest_options(Some(ManifestOptions::default()/* use setters */));
let x = LiveSession::new().set_or_clear_manifest_options(None::<ManifestOptions>);Sourcepub fn set_gam_settings<T>(self, v: T) -> Selfwhere
T: Into<GamSettings>,
pub fn set_gam_settings<T>(self, v: T) -> Selfwhere
T: Into<GamSettings>,
Sets the value of gam_settings.
Example
use google_cloud_video_stitcher_v1::model::live_session::GamSettings;
let x = LiveSession::new().set_gam_settings(GamSettings::default()/* use setters */);Sourcepub fn set_or_clear_gam_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<GamSettings>,
pub fn set_or_clear_gam_settings<T>(self, v: Option<T>) -> Selfwhere
T: Into<GamSettings>,
Sets or clears the value of gam_settings.
Example
use google_cloud_video_stitcher_v1::model::live_session::GamSettings;
let x = LiveSession::new().set_or_clear_gam_settings(Some(GamSettings::default()/* use setters */));
let x = LiveSession::new().set_or_clear_gam_settings(None::<GamSettings>);Sourcepub fn set_live_config<T: Into<String>>(self, v: T) -> Self
pub fn set_live_config<T: Into<String>>(self, v: T) -> Self
Sets the value of live_config.
Example
let x = LiveSession::new().set_live_config(format!("projects/{project_id}/locations/{location_id}/liveConfigs/{live_config_id}"));Sourcepub fn set_ad_tracking<T: Into<AdTracking>>(self, v: T) -> Self
pub fn set_ad_tracking<T: Into<AdTracking>>(self, v: T) -> Self
Sets the value of ad_tracking.
Example
use google_cloud_video_stitcher_v1::model::AdTracking;
let x0 = LiveSession::new().set_ad_tracking(AdTracking::Client);
let x1 = LiveSession::new().set_ad_tracking(AdTracking::Server);Trait Implementations
Sourceimpl Clone for LiveSession
impl Clone for LiveSession
Sourcefn clone(&self) -> LiveSession
fn clone(&self) -> LiveSession
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for LiveSession
impl Debug for LiveSession
Sourceimpl Default for LiveSession
impl Default for LiveSession
Sourcefn default() -> LiveSession
fn default() -> LiveSession
Sourceimpl Message for LiveSession
impl Message for LiveSession
Sourceimpl PartialEq for LiveSession
impl PartialEq for LiveSession
Sourcefn eq(&self, other: &LiveSession) -> bool
fn eq(&self, other: &LiveSession) -> bool
self and other values to be equal, and is used by ==.